==> open-xchange-realtime-atmosphere_7.2.1.orig.tar.bz2: open-xchange-realtime-atmosphere-7.2.1/com.openexchange.realtime.atmosphere/src/com/openexchange/realtime/atmosphere/impl/EnqueuedStanza.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.realtime.atmosphere.impl;

import com.openexchange.realtime.packet.Stanza;


/**
 * {@link EnqueuedStanza}
 *
 * @author <a href="mailto:francisco.laguna@open-xchange.com">Francisco Laguna</a>
 */
public class EnqueuedStanza implements Comparable<EnqueuedStanza>{
    
    static final int INFINITY = 100;
    
    public Stanza stanza;
    public long sequenceNumber;
    public int count;
    
    public EnqueuedStanza(Stanza stanza) {
        this.stanza = stanza;
        this.sequenceNumber = stanza.getSequenceNumber();
        this.count = 0;
    }
    
    public EnqueuedStanza(long sequenceNumber) {
        this.sequenceNumber = sequenceNumber;
    }
    
    public boolean incCounter() {
        synchronized(stanza) {
            count++;
            if (count > INFINITY) {
                return false;
            }
            return true;
        }
    }

    @Override
    public int compareTo(EnqueuedStanza o) {
        return (int) (sequenceNumber - o.sequenceNumber);
    }
    
    @Override
    public boolean equals(Object obj) {
        return ((EnqueuedStanza)obj).sequenceNumber == sequenceNumber;
    }
}

==> open-xchange-realtime-atmosphere_7.2.2.orig.tar.bz2: open-xchange-realtime-atmosphere-7.2.2/com.openexchange.realtime.atmosphere/src/com/openexchange/realtime/atmosphere/impl/EnqueuedStanza.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.realtime.atmosphere.impl;

import com.openexchange.realtime.packet.Stanza;


/**
 * {@link EnqueuedStanza}
 *
 * @author <a href="mailto:francisco.laguna@open-xchange.com">Francisco Laguna</a>
 */
public class EnqueuedStanza implements Comparable<EnqueuedStanza>{
    
    static final int INFINITY = 100;
    
    public Stanza stanza;
    public long sequenceNumber;
    public int count;
    
    public EnqueuedStanza(Stanza stanza) {
        this.stanza = stanza;
        this.sequenceNumber = stanza.getSequenceNumber();
        this.count = 0;
    }
    
    public EnqueuedStanza(long sequenceNumber) {
        this.sequenceNumber = sequenceNumber;
    }
    
    /**
     * Increment the counter of this enqueued Stanza until the configured maximum count was reached. 
     * @return true if the counter could be incremented, false if incrementing the counter would exceed the configured limit.
     */
    public boolean incCounter() {
        synchronized(stanza) {
            count++;
            if (count > INFINITY) {
                return false;
            }
            return true;
        }
    }

    @Override
    public int compareTo(EnqueuedStanza o) {
        return (int) (sequenceNumber - o.sequenceNumber);
    }
    
    @Override
    public boolean equals(Object obj) {
        return ((EnqueuedStanza)obj).sequenceNumber == sequenceNumber;
    }
}
